@@ -8,7 +8,7 @@ use Blatte::Ws;
 
 use vars qw($identifier_regex);
 
-$identifier_regex = qr/[A-Za-z][A-Za-z0-9_]*(?![A-Za-z0-9_])/;
+$identifier_regex = qr/[A-Za-z][A-Za-z0-9_]*/;
 
 sub new {
   my $type = shift;
@@ -63,7 +63,7 @@ sub expr {
     $input = substr($input, 1);
   } elsif ($input =~ /^\\\"([^\\]+|\\[^\"])*\\\"/g) {
     my $str = substr($input, 0, pos($input));
-    $input = substr($input, pos($input));
+    my $input = substr($input, pos($input));
     $str = substr($str, 2, length($str) - 4);
     $str =~ s/\\(.)/$1/g;
     $syntax = new Blatte::Syntax::Literal($str);
@@ -127,7 +127,7 @@ sub special_form {
 
   my $input = $input_arg;
   if (ref($input)) {
-    $input = $$input_arg;
+    $input = $$input;
   }
 
   my $syntax;
@@ -174,7 +174,7 @@ sub define_var_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\define(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\define/);
   $input = substr($input, 7);
 
   &consume_whitespace(\$input);
@@ -203,7 +203,7 @@ sub define_fn_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\define(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\define/);
   $input = substr($input, 7);
 
   &consume_whitespace(\$input);
@@ -245,7 +245,7 @@ sub set_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\set!(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\set!/);
   $input = substr($input, 5);
 
   &consume_whitespace(\$input);
@@ -274,7 +274,7 @@ sub lambda_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\lambda(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\lambda/);
 
   $input = substr($input, 7);
 
@@ -349,7 +349,7 @@ sub any_let_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\(letrec|let\*?)(?![A-Za-z0-9_])/g);
+  return undef unless ($input =~ /^\\(letrec|let\*?)/g);
   my $keyword = $1;
   $input = substr($input, pos($input));
 
@@ -432,7 +432,7 @@ sub if_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\if(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\if/);
   $input = substr($input, 3);
 
   my $test = $self->expr(\$input);
@@ -461,7 +461,7 @@ sub cond_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\cond(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\cond/);
   $input = substr($input, 5);
 
   my @clauses;
@@ -500,7 +500,7 @@ sub while_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\while(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\while/);
   $input = substr($input, 6);
 
   my $test = $self->expr(\$input);
@@ -526,7 +526,7 @@ sub and_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\and(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\and/);
   $input = substr($input, 4);
 
   my @exprs = $self->exprs(\$input);
@@ -550,7 +550,7 @@ sub or_expr {
   }
 
   &consume_whitespace(\$input);
-  return undef unless ($input =~ /^\\or(?![A-Za-z0-9_])/);
+  return undef unless ($input =~ /^\\or/);
   $input = substr($input, 4);
 
   my @exprs = $self->exprs(\$input);
@@ -651,9 +651,6 @@ Blatte::Parser - parser for Blatte syntax
 
 =head1 DESCRIPTION
 
-A parser for turning written Blatte expressions into their Perl
-equivalents or into Blatte's syntax-tree representation.
-
 =head1 METHODS
 
 =over 4
@@ -675,9 +672,9 @@ family of objects.
 
 =item $parser->eof(INPUT)
 
-Tests INPUT for end-of-file.  Leading whitespace is removed from INPUT
-with consume_whitespace and, if nothing remains, true is returned,
-else undef.
+Parses an end-of-file from INPUT.  Return value is 1 if no Blatte
+expressions remain in INPUT (that is, if it's empty after a call to
+consume_whitespace()), undef otherwise.
 
 =back
 
