@@ -612,8 +612,7 @@ sub transform {
   sprintf('(%s)',
           join(sprintf("\n%s && ", $indent),
                map {
-                 sprintf('&Blatte::true(%s)',
-                         &Blatte::Syntax::transform($_, $column + 18));
+                 &Blatte::Syntax::transform($_, $column + 4);
                } $self->exprs()));
 }
 
@@ -636,8 +635,7 @@ sub transform {
   sprintf('(%s)',
           join(sprintf("\n%s || ", $indent),
                map {
-                 sprintf('&Blatte::true(%s)',
-                         &Blatte::Syntax::transform($_, $column + 18));
+                 &Blatte::Syntax::transform($_, $column + 4);
                } $self->exprs()));
 }
 
